/**
 *       Copyright (C) Danish Wireless Design A/S. All rights reserved.
 *
 * This document contains proprietary information belonging to Danish Wireless
 * Design A/S. Passing on and copying of this document, use and communication
 * of its contents is not permitted without prior written authorisation.
 *
 * Description:
 *   Contains definitions of all eep parameters
 *
 * Revision Information:
 *   File name: \dwdsrc\P2000\EE_64K\src\eep.h
 *   Version: \main\37
 *   Date: 2003-01-21 14:02:41
 *   Responsible: ec
 *   Comment:
 *     - New function EEP_delta_update_done.
 *     - EEP version and revision at fixed addesses.
 */


#ifndef _EEP_H
#define _EEP_H

/* Use common types for PC and target */
#ifndef _WIN32
 #define int16  int
 #define int32  long
#else
 #define int16  short int
 #define int32  int
 #define shuge 
#endif

/*--------------------------------------------*/
/* External functions.                        */
/*--------------------------------------------*/
extern unsigned int EEP_get_version(void);
extern unsigned int EEP_get_revision(void);
extern unsigned int EEP_get_original_version(void);
extern unsigned int EEP_get_original_revision(void);
extern void         EEP_get_size(unsigned int *static_size, unsigned int *dynamic_size);
extern unsigned int EEP_get_internal_data(unsigned char *dst, unsigned int offset, unsigned int nof);
extern unsigned int EEP_write_internal_data(unsigned char *src, unsigned int offset, unsigned int nof);
extern unsigned int EEP_delta_update_done(void);

/*---------------------------------------------*/
/* Defines:                                    */
/*---------------------------------------------*/
/* IMPORTANT:*/
/* Remember always to change EEP_VERSION when the eep structures has changed */

// version control by Sammy Chen
// This is for 2048, and mapping to DWD version 31
#define EEP_VERSION                 51129//51128//51127  //Modified by Yulin at 2003/11/17 for new add Program of CAMERA  51126 //modified by Yun Lee, 20030702
#define EEP_REVISION                0

/* NOTE: Remember to change this whenever "EEP_dynamic_factory[]" is modyfied !!! */
#ifdef _64K_DYN_EEPROM
#define EEP_DYNAMIC_FACTORY_SIZE  38304//38298//modified by Yulin 20031117 //38284//38244//59396  //modified by Yun Lee, 20030707
  										//59346
  
#else
  #define EEP_DYNAMIC_FACTORY_SIZE 12244
#endif

#define EEPRF_NOF_BANDS              2
#define EEPRF_NOF_RXLEV_OFFSETS     70

#define EEPCHR_NOF_BAT               2
#define EEPCHR_MAX_NOF_TEMP_INDX     8
#define EEPRF_RX_NOF_CH_INTERV       8

#define ATC_NVR_SCA_LEN             13
#define ATC_NVR_CGMI_LEN            15
#define ATC_NVR_CGMM_LEN            30
#define ATC_NVR_CGMR_LEN            15
#define ATC_NVR_CGSN_LEN            30
#define ATC_NVR_INFO_LEN            17

#define ATC_NVR_GREET_LEN          (50+2)
#define MMI_NVR_CSCA_LEN           (13+2)
#define ATC_NVR_TRACE_LEN           (4+2)
#define ATC_NVR_GSM_PARAMP_LEN    (958+2)
#define ATC_NVR_DCS_PARAMP_LEN   (1022+2)
#define ATC_NVR_PCS_PARAMP_LEN   (1022+2)
#define ATC_NVR_SMSPP_PDU_LEN     (176+2)
#define MS_GPRS_SERVICE_LEN         (4+2)
/* Begin Add by Sammy Chen */
/* 2002-04-20 */
#define ATC_MSG_SERV_SETTINGS_LEN (132+2)


#define NVR_GSM900P      1
#define NVR_GSM900E      2
#define NVR_GSM900R      3
#define NVR_DCS1800      4
#define NVR_PCS1900      5
#define NVR_GSM850       6
#define NVR_GSM450       7
#define NVR_GSM480       8
#define NVR_INVALID_BAND 0xff

/* End Add by Sammy Chen */
#define EEP_AD_ACTIVE                  0 /* handle by the AD driver */
#define EEP_NORMAL_TRACE_ACTIVE        1 /* Handled by the AD driver */
#define EEP_TRACE_FROM_POWER_ON_ACTIVE 2 /* In ms_hwtrc.c? if you like to use this parameter*/

#define EEP_SIZE_AFC_TEMP_OFFSET       40 

/* Begin - Add By Sammy Chen for Comneon Rel 4.0.3 */
/* PLMN list definitions of size boundaries */ 
#define EEP_MSAP_PLMN_LONG_NAME_LENGTH	24
#define EEP_MSAP_PLMN_SHORT_NAME_LENGTH	10
#define EEP_FLASH_PLMN_LIST_LENGTH      30


/* SIM TK terminal profile */
#define EEP_MAX_TERM_PROFILE_LEN 30
/* End - Add By Sammy Chen for Comneon Rel 4.0.3 */
/*---------------------------------------------*/
/* Type definitions.                           */
/*---------------------------------------------*/
/* RF TX adjusted compensation parameters */
typedef struct
{
   signed char rampup;
   signed char rampdown;
} eeprf_pa_timing_elm_type;


typedef eeprf_pa_timing_elm_type eeprf_pa_timing_offset_type[EEPRF_NOF_BANDS][20];


typedef signed int16 eeprf_pa_offset_compensation_type[EEPRF_NOF_BANDS][20];


typedef unsigned char eeprf_pa_v_home_compensation_type[EEPRF_NOF_BANDS][20];


/* RF TX compensation parameter types */
typedef signed char eeprf_pa_max_pwr_ch_comp_type[EEPRF_NOF_BANDS][4];
/*
   signed char gsm_r1_25;
   signed char gsm_r26_99;
   signed char gsm_r100_124;
   signed char gsm_r975_1023;
   signed char pcn_r512_600;
   signed char pcn_r601_700;
   signed char pcn_r701_800;
   signed char pcn_r801_886;*/





typedef signed char eeprf_pa_max_pwr_temp_comp_type[EEPRF_NOF_BANDS][5];
/*   signed char gsm_rm30_m11;
     signed char gsm_rm10_9;
     signed char gsm_r10_29;
     signed char gsm_r30_49;
     signed char gsm_r50_70;
     signed char pcn_rm30_m11;
     signed char pcn_rm10_9;
     signed char pcn_r10_29;
     signed char pcn_r30_49;
     signed char pcn_r50_69;*/


typedef struct
{
   unsigned int16  threshold;
   unsigned int16  offset_step;
}  eeprf_pa_max_pwr_vcc_comp_elm_type;

typedef eeprf_pa_max_pwr_vcc_comp_elm_type eeprf_pa_max_pwr_vcc_comp_type[EEPRF_NOF_BANDS];

/* RF RX adjusted compensation parms */
typedef signed char eeprf_rxlev_gain_comp_type[EEPRF_NOF_BANDS][EEPRF_NOF_RXLEV_OFFSETS];
typedef signed char eeprf_rxlev_channel_comp_type[EEPRF_NOF_BANDS][EEPRF_RX_NOF_CH_INTERV];

/* RF RX compensation parms */
typedef signed char eeprf_rxlev_temp_comp_type[EEPRF_NOF_BANDS][5];
/*   signed char gsm_rm30_m11;
     signed char gsm_rm10_9;
     signed char gsm_r10_29;
     signed char gsm_r30_49;
     signed char gsm_r50_70;
     signed char pcn_rm30_m11;
     signed char pcn_rm10_9;
     signed char pcn_r10_29;
     signed char pcn_r30_49;
     signed char pcn_r50_69;*/


typedef struct
{
  unsigned int16 default_dac_value;
  unsigned int16 dac_step_gsm_in_hz;
} eeprf_afc_type;


typedef struct
{
  eeprf_pa_offset_compensation_type  pa_offset;
  eeprf_pa_v_home_compensation_type  pa_v_home_offset;
  eeprf_pa_timing_offset_type        pa_timing_offset;
  eeprf_rxlev_gain_comp_type         rxlev_gain_comp;
  eeprf_rxlev_channel_comp_type      rxlev_ch_comp;
  eeprf_afc_type                     afc;
} eeprf_adjusted_comp_parm_type;


typedef struct
{
  eeprf_pa_max_pwr_ch_comp_type    pa_ch_comp;
  eeprf_pa_max_pwr_temp_comp_type  pa_temp_comp;
  eeprf_pa_max_pwr_vcc_comp_type   pa_vcc_comp;
  eeprf_rxlev_temp_comp_type       rxlev_temp_comp;
} eeprf_comp_parm_type;

/* Charger and capacity estimation parameters*/

typedef struct
{
  unsigned int16 charger_last_state;     /* charger state */
  unsigned int16 discharge_rate_traffic; /* capacity parameter */
} eepchr_dynamic_parms_type;


typedef enum
{
  eeprtc_12_hour_format,
  eeprtc_24_hour_format,
  dummy_1 = 1000
} eeprtc_time_format_type;

typedef enum
{
  eeprtc_dd_mm_yy_format,
  eeprtc_mm_dd_yy_format,
  eeprtc_yy_mm_dd_format,
  dummy_2 = 1000
} eeprtc_date_format_type;

typedef unsigned char eeprtc_event_str_type[15];
/* 14 characters + string termination */

typedef struct
{
  unsigned char         year;
  unsigned int16        day;
  unsigned char         hour;
  unsigned char         minute;
  unsigned char         second;
} eeprtc_counter_ref_type;


typedef struct
{
  eeprtc_counter_ref_type  timeout;
  eeprtc_event_str_type    event;
} eeprtc_rtc_event_descr_type;


typedef struct
{
  eeprtc_counter_ref_type     start_ref;
  eeprtc_counter_ref_type     end_ref;
  eeprtc_time_format_type     time_format;
  eeprtc_date_format_type     date_format;
  unsigned int16              nof_events;
  eeprtc_rtc_event_descr_type event;
} eeprtc_dynamic_parms_type;


#ifndef BATTERY_WITH_FUEL_GAUGE

typedef struct
{
  unsigned char  charger_recharge_capacity;
  unsigned char  t_max_fast_charge; 
  unsigned char  t_max_top_charge; 
  signed   char  temp_hi_max; 
  signed   char  temp_hi_hysteresis; 
  signed   char  temp_low_min; 
  unsigned int16 v_max_fast; 
  unsigned int16 v_charge; 
  unsigned char  i_eoc_fast_charge; 
  unsigned char  i_eoc_top_charge; 
  unsigned char  dt_eoc;  		// Add by Sammy Chen 2002-04-20
  unsigned char  dv_eoc;  		// Add by Sammy Chen 2002-04-20
} eepchr_battery_parms_type;

typedef struct
{
  unsigned char  t_reset_no_supply; 
  unsigned char  t_pseudo_charge; 
  unsigned char  t_initial_check; 
  unsigned char  t_pulse_charge; 
  unsigned char  t_pulse_charge_paused; 
  unsigned char  t_trickle_charge_paused; 
  unsigned int16 charger_max_voltage; 
  eepchr_battery_parms_type battery[EEPCHR_NOF_BAT];
  signed char    pmb6253_temp_gain; 
  signed char    pmb6253_temp_offset; 
  unsigned char  window_length; 
} eepchr_default_charger_parms_type;

typedef struct
{
  unsigned char  v_charge_offset; 
  unsigned int16 voltage_vector[8];  
  unsigned char  capacity_vector[8]; 
  unsigned char  tch_drop_vector[8]; 
  unsigned char  r_dc_vector[8];     
  signed char    temperature_vector[8]; 
  unsigned char  capacity_temp_vector[8]; 
} eepchr_capacity_battery_parms_type;

typedef struct
{
  unsigned int16 v_shutdown_idle; 
  unsigned int16 v_shutdown_traffic; 
  unsigned int16 v_low_traffic; 
  unsigned char  battery_low_capacity; 
  unsigned char  backlight_enabled; 
  unsigned char  vibrator_enabled; 
  unsigned char  mp3_player_enabled; 
  unsigned char  camera_enabled; 
  unsigned char  datacable_enabled; 
  unsigned char  chatboard_enabled; 
  unsigned char  idle_mode; 
  unsigned char  tch_load_offset; 
  unsigned char  freeze_load; 
  unsigned int16 t_load_freeze; 
  unsigned int16 i_charger; 
  eepchr_capacity_battery_parms_type battery[EEPCHR_NOF_BAT];
} eepchr_default_capacity_parms_type;

#else 

typedef struct
{
   unsigned int16 v_init_check;
   unsigned int16 v_traffic_hysteresis;
   unsigned char  t_max_fast_charge;
   unsigned char  t_max_top_charge;
   signed   char  temp_hi_max;
   signed   char  temp_hi_hysteresis;
   signed   char  temp_low_min;
   unsigned int16 v_max_fast;
   unsigned int16 v_charge;
   unsigned char  i_eoc;
   unsigned char  dtemp_dt_eoc;
   unsigned char  delta_v_eoc;
} eepchr_battery_parms_type;


typedef struct
{
  unsigned char charger_t_reset_no_supply;
  unsigned char charger_t_pseudo_charge;
  unsigned char charger_t_initial_check;
  unsigned char charger_i_external_supply;
  unsigned char charger_recharge_capacity;
  eepchr_battery_parms_type battery[EEPCHR_NOF_BAT];
  signed int16  pmb6253_temp_gain;     /* Values to be found in PMB 6253 data sheet */
  unsigned char window_length;
} eepchr_default_charger_parms_type;


typedef struct
{
  unsigned int16 nomcap;
  unsigned char  sdr;
  unsigned char  chgeff;
  unsigned char  chgm[EEPCHR_MAX_NOF_TEMP_INDX];
  unsigned char  dchgm[EEPCHR_MAX_NOF_TEMP_INDX];
  unsigned char  tempacc[EEPCHR_MAX_NOF_TEMP_INDX];
  unsigned char  fade;
  unsigned int16 maxchange;
} eepchr_capacity_battery_parms_type;

typedef struct
{
  unsigned int16 v_shutdown_idle;
  unsigned int16 v_shutdown_traffic;
  unsigned int16 delta_v_lowbatt;
  unsigned char battery_low_capacity;
  eepchr_capacity_battery_parms_type battery[EEPCHR_NOF_BAT];
} eepchr_default_capacity_parms_type;

#endif


typedef struct
{
  signed int16 vbat_gain;
  signed int16 vbat_offset;
  signed int16 tbat_gain;
  signed int16 tbat_offset;
  signed int16 tenv_gain;
  signed int16 tenv_offset;
  signed int16 btec_gain;
  signed int16 btec_offset;
  signed int16 tvco_gain;
  signed int16 tvco_offset;
} eepchr_adc_adjusted_comp_parms_type;


typedef struct
{
  signed int16 chr_eep_mic_resistor_offset;
} eepchr_mic_parms_type;

typedef struct
{
  unsigned int16 disable_external_audio;
} eep_external_audio_type;

typedef struct
{
  unsigned int16 valid_value;
} eepchr_gg_dram_type;

typedef struct
{
  signed int16  temp_offset;   /* Values to be found in PMB 6253 data sheet */
} eepchr_pmb6253_type;


enum eepatc_modes
{
  eepatc_startup_wait_for_arfcn, /* wait for arfcn from test mode */
  eepatc_startup_use_arfcn_in_eep,
  eep_atc_default_startup,
  eep_HS_disable_startup=5,		/*Tony Shu add*/
  dummy_3 = 1000
};

typedef struct
{
  unsigned int16 mode;
  unsigned int16 arfcn;
} eepatc_startup_info_type;


/* Audio driver type definitions */
typedef struct  /* Voiceband parameters */
{
  signed int16         scal_mic;
  signed int16         gain_out;
  signed int16         mix_fact_speech;
  signed int16         mix_fact_tone;
  signed int16         tone_amp;
}aud_gain_cells_type;

typedef struct  /* Parameters for the digital filters */
{
  signed int16         in1[5];
  signed int16         in2[5];
  signed int16         out1[5];
  signed int16         out2[5];
}aud_filter_type;


typedef struct
{
  signed int16         hf_algorithm_init;
  signed int16         hf_algorithm_restart;
  signed int16         step_width;
  signed int16         lms_length;
  signed int16         lms_offset;
  signed int16         block_length;
  signed int16         rxtx_relation;
  signed int16         add_atten;
  signed int16         min_atten;
  signed int16         max_atten;
  signed int16         nr_sw_2;
  signed int16         nr_u_fak_0;
  signed int16         nr_u_fak;  
}aud_hf_type;


typedef struct
{
  signed   int16       scal_rec[9];
  signed   int16       side_tone_fact[9];
  unsigned int16       gaim_reg[9];
}aud_volume_type;

typedef struct
{
  aud_gain_cells_type  gain_cells;
  aud_filter_type      filter;
  aud_hf_type          hf;
  aud_volume_type      volume;
  signed int16         mic_mute;
  unsigned char        fill_char[23];
}eepaud_default_dsp_parms_type;

typedef struct
{
  signed int16         scal_in;
  signed int16         scal_out;
}eepaud_static_parms_type;

typedef struct
{
  unsigned char      actual_buzzer_volume;
  unsigned char      actual_speaker_volume;
}eepaud_dynamic_parms_type;


/* LCD parameters: */

typedef enum
{
  densitron    = 0,
  rohm         = 1,
  densitron_c2 = 2,
  dummy_4      = 1000
} lcd_id_type;


typedef struct
{
  unsigned int16     text_flash_time;
}eeplcd_default_display_parms_type;


typedef struct
{
  lcd_id_type        id;
  unsigned char      contrast_ctrl_reg;
}eeplcd_static_display_parms_type;


/* Production parameters */

typedef struct
{
  unsigned int16 ver;// modified by Yun Lee, Ares Shanghai, 2002/12/25 
  //unsigned char ver;
  unsigned char rev;
} eep_version_type;


typedef struct
{
  unsigned int16   id;
  unsigned int16   hw_version;
  eep_version_type eep_version;
} eep_config_type;


typedef eep_config_type eep_updated_config_type;
typedef eep_config_type eep_original_config_type;


typedef struct
{
  unsigned int16 result;
  unsigned int16 nof_tests;
  unsigned int16 version;
  unsigned int16 sw_version;
  unsigned int16 spec;
  unsigned int16 testsite_id;
} eep_test_station_type;

typedef eep_test_station_type eep_inline_test_type;
typedef eep_test_station_type eep_calib_test_type;
typedef eep_test_station_type eep_mmi_test_type;

typedef struct
{
  unsigned char year;
  unsigned char month;
  unsigned char week;
  unsigned char day;
} eep_production_date_type;

typedef struct
{
  unsigned int16 param_1;
  unsigned int16 param_2;
  unsigned int16 param_3;
  unsigned int16 param_4;
  unsigned int16 param_5;
  unsigned int16 param_6;
  unsigned int16 param_7;
  unsigned int16 param_8;
  unsigned int16 param_9;
} eep_customer_parm_type;

typedef struct
{
  unsigned int32           serial_no;
  unsigned int16           testseries_id;
  eep_config_type          orig_conf;
  eep_config_type          upd_conf;
  eep_test_station_type    in_line;
  eep_test_station_type    calib;
  eep_test_station_type    mmi;
  eep_production_date_type date;
  eep_customer_parm_type   cust_parms;
} eep_production_parm_type;


/* Graphical greeting */
typedef struct
{
  unsigned char pmi_greeting_graphic[452];
} eep_greeting_graphic_type;



/* MMI parameters */
typedef struct
{
 unsigned char pmi_default_divert_number_2[41];	
 unsigned char pmi_greeting_message_text[32];
 unsigned char pmi_backlight_status[2];
 unsigned char pmi_auto_redial_on_off[2];

//added by Yulin at 2003/11/17 for new add Program of CAMERA start
 unsigned char pmi_camera_banding[2];
 unsigned char pmi_camera_pic_quality[2];
 unsigned char pmi_camera_sound[2];
 unsigned char pmi_camera_drive_mode[2];
 unsigned char pmi_camera_condition[2];
 unsigned char pmi_camera_brightness[2];
 unsigned char pmi_camera_special_effect[2];
 unsigned char pmi_camera_take_style[2];//the style for taken photo,i.e. user defined time	
 unsigned char pmi_camera_time_user_def[2];
 unsigned char pmi_camera_delay_time[2];
//added by Yulin at 2003/11/17 for new add Program of CAMERA end
 	
 unsigned char pmi_any_key_answer[2];
 unsigned char pmi_encryption[2];
 unsigned char pmi_key_tone[2];
 unsigned char pmi_msg_alert_tone[2];
 unsigned char pmi_msg_alert_volume[2];
 unsigned char pmi_out_id_shown[2];
 unsigned char pmi_ring_tone[2];
 unsigned char pmi_ring_volume[2];
 unsigned char pmi_save_volume[2];
 unsigned char pmi_vibrator[2];
 unsigned char pmi_t9_mode[2];
 unsigned char pmi_costs_last_call[22];
 unsigned char pmi_acm_time[22];
 unsigned char pmi_costs_hplmn_calls[10];
 unsigned char pmi_costs_fplmn_calls[10];
 unsigned char pmi_hplmn_call_rate[10];
 unsigned char pmi_fplmn_call_rate[10];
 unsigned char pmi_plmn_search_method[2];
 unsigned char pmi_last_accepted_call_1[46];
 unsigned char pmi_last_accepted_call_2[46];
 unsigned char pmi_last_accepted_call_3[46];
 unsigned char pmi_last_accepted_call_4[46];
 unsigned char pmi_last_accepted_call_5[46];
 unsigned char pmi_last_accepted_call_6[46];
 unsigned char pmi_last_accepted_call_7[46];
 unsigned char pmi_last_accepted_call_8[46];
 unsigned char pmi_last_accepted_call_9[46];
 unsigned char pmi_last_accepted_call_10[46];
 unsigned char pmi_last_missed_call_1[46];
 unsigned char pmi_last_missed_call_2[46];
 unsigned char pmi_last_missed_call_3[46];
 unsigned char pmi_last_missed_call_4[46];
 unsigned char pmi_last_missed_call_5[46];
 unsigned char pmi_last_missed_call_6[46];
 unsigned char pmi_last_missed_call_7[46];
 unsigned char pmi_last_missed_call_8[46];
 unsigned char pmi_last_missed_call_9[46];
 unsigned char pmi_last_missed_call_10[46];
 /*======= Add by William Lo ========*/
 unsigned char pmi_last_dialled_call_1[46];
 unsigned char pmi_last_dialled_call_2[46];
 unsigned char pmi_last_dialled_call_3[46];
 unsigned char pmi_last_dialled_call_4[46];
 unsigned char pmi_last_dialled_call_5[46];
 unsigned char pmi_last_dialled_call_6[46];
 unsigned char pmi_last_dialled_call_7[46];
 unsigned char pmi_last_dialled_call_8[46];
 unsigned char pmi_last_dialled_call_9[46];
 unsigned char pmi_last_dialled_call_10[46];
 unsigned char pmi_cmc_last_call[12];
 unsigned char pmi_cmc_outgo_call[12];
 unsigned char pmi_cmc_incom_call[12];
 unsigned char pmi_cmc_auto_display;
 unsigned char pmi_all_or_incom_calls;
 unsigned char pmi_ac_limit_on_off;
 unsigned char pmi_cmc_per_min[6];
 /*======= Add end =======*/
 unsigned char missed_call_flag[2];
 unsigned char pmi_sim_lock_pck[14];
 unsigned char pmi_sim_lock_imsi[10];
 unsigned char pmi_sim_only_imsi[10];	 	// Add by Sammy Chen , 2002-04-16
 unsigned char pmi_sim_lock_on_off[2];
 unsigned char pmi_sms_validity[2];
 unsigned char pmi_sc_number[12];
 unsigned char pmi_speaker_volume[2];
 unsigned char pmi_keypad_lock_state[2];
 unsigned char pmi_call_display_timer[2];
 unsigned char pmi_alarm_time[5];		// modify by Sammy Chen 07-31-2002 ,pmi_alarm_time[8]
 unsigned char pmi_language[2];
 unsigned char pmi_plmn_list_entry_1[20];
 unsigned char pmi_plmn_list_entry_2[20];
 unsigned char pmi_plmn_list_entry_3[20];
 unsigned char pmi_plmn_list_entry_4[20];
 unsigned char pmi_plmn_list_entry_5[20];
 unsigned char pmi_plmn_list_entry_6[20];
 unsigned char pmi_plmn_list_entry_7[20];
 unsigned char pmi_plmn_list_entry_8[20];
 unsigned char pmi_plmn_list_entry_9[20];
 unsigned char pmi_plmn_list_entry_10[20];
 unsigned char pmi_sms_class_0[176];
 unsigned char pmi_spl_pwd[14];
 unsigned char pmi_spl_unlock_code[10];
 unsigned char pmi_speed_dialling_on_off[2];
 unsigned char pmi_aoc_flag[2];
 unsigned char pmi_call_logging_on_off[2];
 unsigned char pmi_lnd_1[24];
 unsigned char pmi_lnd_2[24];
 unsigned char pmi_lnd_3[24];
 unsigned char pmi_lnd_4[24];
 unsigned char pmi_lnd_5[24];
 unsigned char pmi_lnd_6[24];
 unsigned char pmi_lnd_7[24];
 unsigned char pmi_lnd_8[24];
 unsigned char pmi_lnd_9[24];
 unsigned char pmi_lnd_10[24];
 unsigned char pmi_manual_selected_plmn[4];
 unsigned char sim_lock_duration[4];
 unsigned char pmi_call_divert_status[2];

 unsigned char pmi_simtk_poll_intervall[2];
 unsigned char pmi_simtk_menu[258];
 unsigned char pmi_simtk_menu_available[2];
 unsigned char pmi_security_checks[2];
 unsigned char pmi_operation_mode[2];
 unsigned char pmi_fdn_mode[2];
 unsigned char simtk_cmd_active[2];

 unsigned char pmi_charging_mode[2];

 unsigned char pmi_auto_power_off[2];
 unsigned char pmi_phb_melody_id[256];
 unsigned char pmi_minute_indicator[2];
 unsigned char pmi_audio_off[2];
 unsigned char pmi_letter_case[2];
 unsigned char pmi_contrast[2];
 unsigned char pmi_phone_code[4];
 unsigned char pmi_als_line[2];
  unsigned char pmi_internal_phb[46*100];// added by sinva ma shanghai ares 2002/12/09
// unsigned char pmi_internal_phb[46*50];	// Modify by Sammy Chen , 2002-04-18  unsigned char pmi_internal_phb[2300];
 unsigned char pmi_t9_activation_state[2];
 unsigned char pmi_t9_language[2];
 unsigned char pmi_hot_key[10];
 unsigned char pmi_cell_broadcast[2];
 unsigned char pmi_sms_profile_1[18];
 unsigned char pmi_sms_profile_2[18];
 unsigned char pmi_sms_profile_3[18];
 unsigned char pmi_sms_profile_4[18];
 unsigned char pmi_internal_sms[4200];// 210 bytes * 20, Modify by William Lo, 2002/05/24
 unsigned char pmi_sms_message_status[20]; // William Lo, 2002/05/23
 unsigned char proactive_dtmf_tones[2];
 /*======= Add by William Lo=======*/
 unsigned char pmi_phonebook_group_1[33];
 unsigned char pmi_phonebook_group_2[33];
 unsigned char pmi_phonebook_group_3[33];
 unsigned char pmi_phonebook_group_4[33];
 unsigned char pmi_phonebook_speed_dial_key[9*2];	/* Add by Sammy Chen, 07-08-2002 */
 unsigned char pmi_meadn_index[100];//added by sinva ma shanghai ares 2002/12/09
// unsigned char pmi_meadn_index[50];
 
  unsigned char pmi_peter_airplane_mode_on_off;
  //Language
	//unsigned char pmi_peter_language;			// Remove by Sammy Chen , 2002-04-23
  //Device
	//Display
	unsigned char pmi_peter_greeting_on_off;
	unsigned char pmi_peter_operator_logo_on_off;
	//unsigned char pmi_peter_illumination_on_off;	// Remove by Sammy Chen , 2002-04-23
	unsigned char pmi_peter_big_letter_on_off;
	unsigned char pmi_peter_contrast;
	unsigned char pmi_peter_greeting_type;
	unsigned char pmi_peter_greeting_length;
	//Key
	//unsigned char pmi_peter_any_key_answer_on_off;	// Remove by Sammy Chen , 2002-04-23
	unsigned char pmi_peter_auto_key_lock_on_off;
	//unsigned char pmi_peter_key_tones_on_off;	// Remove by Sammy Chen , 2002-04-23
	//unsigned char pmi_peter_key_tones;		// Remove by Sammy Chen , 2002-04-23
	//T9
	unsigned char pmi_peter_t9_language;
	unsigned char pmi_peter_t9_chinese_bopomofo_on_off;
	unsigned char pmi_peter_t9_chinese_pinyin_on_off;
	unsigned char pmi_peter_t9_chinese_stroke_t_on_off;
	unsigned char pmi_peter_t9_chinese_stroke_s_on_off;
	unsigned char pmi_peter_t9_chinese_associated_on_off;
	//Headset
	unsigned char pmi_peter_auto_anser_on_off; 
	unsigned char pmi_peter_ringer_setting;
	//unsigned char pmi_peter_silent_alert_on_off;		// Remove by Sammy Chen , 2002-04-23
	//unsigned char pmi_peter_volume;				// Remove by Sammy Chen , 2002-04-23
	unsigned char pmi_peter_melody_any_call_both_line;
	unsigned char pmi_peter_melody_any_call_line1;
	unsigned char pmi_peter_melody_any_call_line2;
	unsigned char pmi_peter_melody_pb_call;
	unsigned char pmi_peter_melody_group_call_vip;
	unsigned char pmi_peter_melody_group_call_leisure;
	unsigned char pmi_peter_melody_group_call_office;
	unsigned char pmi_peter_melody_group_call_family;
	unsigned char pmi_peter_melody_alarm;
	unsigned char pmi_peter_melody_message;
	unsigned char pmi_peter_melody_cell_broadcast;
	//unsigned char pmi_peter_call_screen_on_off;		// Remove by Sammy Chen , 2002-04-23
	unsigned char pmi_peter_call_screen;
	//unsigned char pmi_peter_key_tone_on_off;		// Remove by Sammy Chen , 2002-04-23
	//unsigned char pmi_peter_key_tone;				// Remove by Sammy Chen , 2002-04-23
	unsigned char pmi_peter_minute_beep_on_off;
	unsigned char pmi_peter_info_tone_on_off;
	unsigned char pmi_peter_info_tone_extend_on_off;
	unsigned char pmi_peter_operator_logo;
	unsigned char pmi_peter_quiet_active;		// Add by Sammy Chen , 2002-04-23
	/*
	unsigned char pmi_key_tone_q;				// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_peter_ringer_setting_q;			// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_vibrator_q;				// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_ring_volume_q;				// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_peter_melody_any_call_both_line_q;		// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_peter_melody_any_call_line1_q;		// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_peter_melody_any_call_line2_q;		// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_peter_melody_pb_call_q	;		// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_peter_melody_group_call_vip_q;		// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_peter_melody_group_call_leisure_q;		// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_peter_melody_group_call_office_q;		// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_peter_melody_group_call_family_q;		// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_peter_melody_alarm_q;			// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_peter_melody_message_q;			// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_peter_melody_cell_broadcast_q;		// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_peter_minute_beep_on_off_q;		// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_peter_info_tone_on_off_q;			// Add by Sammy Chen , 2002-05-03
	unsigned char pmi_peter_info_tone_extend_on_off_q	;	// Add by Sammy Chen , 2002-05-03
	*/
	
  //*** MMI setting default value start ***//
  unsigned char pmi_backlight_on_off_def;
  unsigned char pmi_any_key_answer_def;
  unsigned char pmi_key_tone_def;
  unsigned char pmi_language_def;
  unsigned char pmi_vibrator_def;
  unsigned char pmi_ring_volume_def;
  
  unsigned char pmi_peter_airplane_mode_on_off_def;
  unsigned char pmi_peter_greeting_on_off_def;
  unsigned char pmi_peter_operator_logo_on_off_def;
  unsigned char pmi_peter_big_letter_on_off_def;
  unsigned char pmi_peter_contrast_def;
  unsigned char pmi_peter_greeting_text_def;
  unsigned char pmi_peter_auto_key_lock_on_off_def;
  unsigned char pmi_peter_t9_language_def;
  unsigned char pmi_peter_t9_chinese_bopomofo_on_off_def;
  unsigned char pmi_peter_t9_chinese_pinin_on_off_def;
  unsigned char pmi_peter_t9_chinese_stroke_t_on_off_def;
  unsigned char pmi_peter_t9_chinese_stroke_s_on_off_def;
  unsigned char pmi_peter_t9_chinese_associated_on_off_def;
  unsigned char pmi_peter_auto_answer_on_off_def;
  unsigned char pmi_peter_ringer_setting_def;
  unsigned char pmi_peter_melody_any_call_both_line_def;
  unsigned char pmi_peter_melody_any_call_line1_def;
  unsigned char pmi_peter_melody_any_call_line2_def;
  unsigned char pmi_peter_melody_pb_call_def;
  unsigned char pmi_peter_melody_group_call_vip_def;
  unsigned char pmi_peter_melody_group_call_leisure_def;
  unsigned char pmi_peter_melody_group_call_office_def;
  unsigned char pmi_peter_melody_group_call_family_def;
  unsigned char pmi_peter_melody_alarm_def;
  unsigned char pmi_peter_melody_message_def;
  unsigned char pmi_peter_melody_cell_broadcast_def;
  unsigned char pmi_peter_call_screen_def;
  unsigned char pmi_peter_minute_beep_on_off_def;
  unsigned char pmi_peter_info_tone_on_off_def;
  unsigned char pmi_peter_info_tone_extend_on_off_def;
  unsigned char pmi_peter_quiet_active_def;
  unsigned char pmi_key_tone_q_def;
  unsigned char pmi_peter_ringer_setting_q_def;
  unsigned char pmi_vibrator_q_def;
  unsigned char pmi_ring_volume_q_def;
  
  unsigned char pmi_peter_melody_any_call_both_line_q_def;
  unsigned char pmi_peter_melody_any_call_line1_q_def;
  unsigned char pmi_peter_melody_any_call_line2_q_def;
  unsigned char pmi_peter_melody_pb_call_q_def;
  unsigned char pmi_peter_melody_group_call_vip_q_def;
  unsigned char pmi_peter_melody_group_call_leisure_q_def;
  unsigned char pmi_peter_melody_group_call_office_q_def;
  unsigned char pmi_peter_melody_group_call_family_q_def;
  unsigned char pmi_peter_melody_alarm_q_def;
  unsigned char pmi_peter_melody_message_q_def;
  unsigned char pmi_peter_melody_cell_broadcast_q_def;
  unsigned char pmi_peter_minute_beep_on_off_q_def;
  unsigned char pmi_peter_info_tone_on_off_q_def;
  unsigned char pmi_peter_info_tone_extend_on_off_q_def;
  unsigned char pmi_setup_prompt_in_call;				/* Add by Sammy Chen, 07-10-2002 */
  unsigned char pmi_setup_backlight_period;			/* Add by Sammy Chen, 07-10-2002 */
  unsigned char pmi_setup_backlight_period_manual;	/* Add by Sammy Chen, 07-10-2002 */
  //*** MMI setting default value end ***//
  
	unsigned char pmi_phonecode_error_input_time;
	unsigned char pmi_this_sim_only_switch[2];		//Modify by Sammy Chen , 2002/04/16
	unsigned char pmi_last_10_only_switch[2];		//Modify by Sammy Chen , 2002/04/16
	unsigned char pmi_angela_phone_code[8];
	unsigned char pmi_auto_off_switch_state[2];
	unsigned char pmi_auto_off_time[5];
	unsigned char pmi_alarm_be_pressed_flag[2];	/* Add by Sammy Chen, 05-03-2002 */
	
	unsigned char pmi_fak;
	unsigned char pmi_fdk_array[8];
	
	unsigned char pmi_configurable_melody_1[200];
  unsigned char pmi_configurable_melody_2[200];
  unsigned char pmi_configurable_melody_3[200];
  unsigned char pmi_configurable_melody_4[200];
  unsigned char pmi_configurable_melody_5[200];
/*  unsigned char pmi_anim_on_1[833];
  unsigned char pmi_anim_on_2[833];
  unsigned char pmi_anim_on_3[833];
  unsigned char pmi_anim_on_4[833];
  unsigned char pmi_anim_on_5[833];
  unsigned char pmi_anim_on_6[833];
  unsigned char pmi_anim_on_7[833];
  unsigned char pmi_anim_on_8[833];
  unsigned char pmi_anim_on_9[833];
  unsigned char pmi_anim_on_a[833];
  unsigned char pmi_anim_on_b[833];
  unsigned char pmi_anim_on_c[833];
  unsigned char pmi_anim_on_d[833];
  unsigned char pmi_anim_on_e[833];
  unsigned char pmi_anim_on_f[833];
  unsigned char pmi_anim_close_1[833];
  unsigned char pmi_anim_close_2[833];
  unsigned char pmi_anim_close_3[833];
  unsigned char pmi_anim_close_4[833];
  unsigned char pmi_anim_close_5[833];
  unsigned char pmi_anim_close_6[833];
  unsigned char pmi_anim_close_7[833];
  unsigned char pmi_anim_close_8[833];
  unsigned char pmi_anim_close_9[833];
  unsigned char pmi_anim_close_a[833]; */ //remarked by Yun Lee, 20030624
  unsigned char pmi_anim_on_page;
  unsigned char pmi_anim_off_page;
  
  unsigned char pmi_download_logo_1[300];
  unsigned char pmi_download_logo_2[300];
  unsigned char pmi_download_logo_3[300];
  unsigned char pmi_download_logo_4[300];
  unsigned char pmi_download_logo_5[300];
  unsigned char pmi_sms_profile_1_validity;
  unsigned char pmi_sms_profile_2_validity;
  unsigned char pmi_sms_profile_3_validity;
  unsigned char pmi_sms_profile_4_validity;
  unsigned char pmi_sms_profile_1_status;
  unsigned char pmi_sms_profile_2_status;
  unsigned char pmi_sms_profile_3_status;
  unsigned char pmi_sms_profile_4_status;
  /* Begin Add by Sammy Chen , 2002-04-18 */
  unsigned char pmi_sms_profile_1_recipient[18];
  unsigned char pmi_sms_profile_2_recipient[18];
  unsigned char pmi_sms_profile_3_recipient[18];
  unsigned char pmi_sms_profile_4_recipient[18];
  unsigned char pmi_sms_profile_1_message_type;
  unsigned char pmi_sms_profile_2_message_type;
  unsigned char pmi_sms_profile_3_message_type;
  unsigned char pmi_sms_profile_4_message_type;
  unsigned char pmi_sms_profile_1_name[40];
  unsigned char pmi_sms_profile_2_name[40];
  unsigned char pmi_sms_profile_3_name[40];
  unsigned char pmi_sms_profile_4_name[40];
  unsigned char pmi_sms_profile_1_service_center[18];
  unsigned char pmi_sms_profile_2_service_center[18];
  unsigned char pmi_sms_profile_3_service_center[18];
  unsigned char pmi_sms_profile_4_service_center[18];
  unsigned char pmi_sms_profile_1_reply;
  unsigned char pmi_sms_profile_2_reply;
  unsigned char pmi_sms_profile_3_reply;
  unsigned char pmi_sms_profile_4_reply;
  /* End Add by Sammy Chen , 2002-04-18 */
  unsigned char pmi_sms_profile_setting;
  unsigned char pmi_sms_voicemessage_no[/*13*/22]; //add by William Lo 2002/05/15
  //22 modify by tom zhou 2003.1.6

  /* Begin Add by Sammy Chen */
  /* 2002-04-18 */
  // modify by William Lo 2002/05/14
  unsigned char pmi_cb_menu_channel[4*15];
  unsigned char pmi_cb_menu_channel_name[100];
  unsigned char pmi_cb_message_1[1450];//[(2+2+1+2+1406+1)];
  unsigned char pmi_cb_message_2[1450];//[(2+2+1+2+1406+1)];
  unsigned char pmi_cb_message_3[1450];//[(2+2+1+2+1406+1)];
  unsigned char pmi_cb_message_4[1450];//[(2+2+1+2+1406+1)];
  unsigned char pmi_cb_message_5[1450];//[(2+2+1+2+1406+1)];
  unsigned char pmi_cb_message_6[1450];//[(2+2+1+2+1406+1)];
  unsigned char pmi_cb_message_7[1450];//[(2+2+1+2+1406+1)];
  unsigned char pmi_cb_message_8[1450];//[(2+2+1+2+1406+1)];
  unsigned char pmi_cb_message_9[1450];//[(2+2+1+2+1406+1)];
  unsigned char pmi_cb_message_10[1450];//[(2+2+1+2+1406+1)];    
  unsigned char pmi_cb_menu_state;
  unsigned char pmi_cb_menu_languages[2]; 
  // modify end 2002/05/14
  unsigned char pmi_network_fast_search_def;
  unsigned char pmi_network_line_def;
  unsigned char pmi_network_barring_all_outgoing;
  unsigned char pmi_network_barring_all_incoming;
  unsigned char pmi_network_barring_roam;
  unsigned char pmi_network_barring_inter;
  unsigned char pmi_network_barring_home;
  unsigned char pmi_network_call_wait_def;
  unsigned char pmi_network_hide_id_def;
  unsigned char pmi_network_band_def;
  unsigned char pmi_cphs_eep_init;
  /* End Add by Sammy Chen */  
  unsigned char pmi_t9_udb_info[4086+2*5]; //4086 + 5's unsigned short
  unsigned char pmi_default_divert_number[41];
  unsigned char pmi_voice_message_status[2];
  unsigned char pmi_game_vibrate;
  unsigned char pmi_game_backlight;
  unsigned char pmi_game_sound;
  unsigned char pmi_game_vibrate_def;
  unsigned char pmi_game_backlight_def;
  unsigned char pmi_game_sound_def;
  
	// Add end
/*add by Tony Shu 07/01*/
unsigned char pmi_default_divert_second;
unsigned char pmi_alarm_active_type;
unsigned char pmi_autooff_active_type;		/* Add by Sammy Chen, 07-09-2002 */
unsigned char pmi_format_display_mode[2];	/* Add by Sammy Chen, 07-09-2002 */
unsigned char pmi_screensaver_mode[2];	/* Add by Sammy Chen, 07-11-2002 */
unsigned char pmi_wallpaper; /* added by time kang */
unsigned char pmi_iphone_number[50]; /*added by Yun Lee, 2003/03/25*/
signed   int   pmi_contrast_reference; //added by Yun Lee, 20030702 
} eep_mmi_parms_type;


/* SP code  */
typedef struct
{
  unsigned char sp_unlock_code[8];
} eep_sp_unlock_type;


/* Low level trace  */
typedef struct
{
  unsigned char setup[30];
} eep_ll_trace_type;



/* New ATC parameters requested by Comneon: */ 
typedef struct
{
  unsigned char fc_dte;
  unsigned char fc_dce;
} T_AT_FC;

typedef struct
{
  unsigned char len_msb;
  unsigned char len_lsb;
  unsigned char behaviour_ct109;
  unsigned char behaviour_ct108;
  unsigned char behaviour_ct107;
  unsigned char fill_char;           //To ensure correct word allignment
  T_AT_FC       fc;
  unsigned char k;
  unsigned char echo;
  unsigned char resp_suppression;
  unsigned char resp_format;
  unsigned char call_ctrl;
  unsigned char s0;
  unsigned char s2;
  unsigned char s3;
  unsigned char s4;
  unsigned char s5;
  unsigned char s7;
  unsigned char data_rate;
  unsigned char bearer_service;
  unsigned char conn_element;
  signed int16  rlp_iws;
  signed int16  rlp_mws;
  unsigned char rlp_96_t1;
  unsigned char rlp_n2;
  unsigned char service_report_crtl;
  unsigned char result_codes_ctrl;
} atc_nvr_profile_t;

typedef struct
{
  unsigned char len_msb;
  unsigned char len_lsb;
  unsigned char cpms_value1;
  unsigned char cpms_value2;
  unsigned char cpms_value3;
  unsigned char cpms_value4;
  int16         csmp_fo;
  int16         csmp_vp;
  int16         csmp_pid;
  int16         csmp_dcs;
  unsigned char cnmi_mt;
  unsigned char cnmi_ds;
  unsigned char cmgf;
  unsigned char cscb;
  unsigned char csdh;
  unsigned char csms;
  unsigned char cscs;
} atc_sms_profile_t;

/* Begin Add by Sammy Chen */
/* 2002-04-20 */
typedef struct
{
 unsigned char    len_msb;
 unsigned char    len_lsb;
 unsigned char    sca[26];
 unsigned int16   csmp_fo;
 unsigned int16   csmp_vp;
 unsigned char    csmp_vp_str[15];
 unsigned int16   csmp_pid;
 unsigned int16   csmp_dcs;
 unsigned char    cscb_cur_value;
 unsigned char    cscb_mid_str[40];
 unsigned char    cscb_dcss_str[40];
 unsigned char    fill_char;            //Ensure correct word allignment
} eep_t_msg_serv_settings;

/* End Add by Sammy Chen */

/* the following values are written once by the manufacturer
** and can not be modified by the user */
typedef struct
{
   unsigned char dummy[94];  
} eep_obsolete_atc_static_parms_type;


/* the following values are written once by the manufacturer
** and can not be modified by the user */
typedef struct
{
   unsigned char     cgmi[ATC_NVR_CGMI_LEN];  /* manufacturer identification */
   unsigned char     cgmm[ATC_NVR_CGMM_LEN];  /* model identification */
   unsigned char     cgmr[ATC_NVR_CGMR_LEN];  /* revision information */
   unsigned char     cgsn[ATC_NVR_CGSN_LEN];  /* serial number identification */

   unsigned char     info_0[ATC_NVR_INFO_LEN]; /* ATI0: manufacturer info */
   unsigned char     info_1[ATC_NVR_INFO_LEN]; /* ATI1: manufacturer info */
   unsigned char     info_2[ATC_NVR_INFO_LEN]; /* ATI2: manufacturer info */
   unsigned char     info_3[ATC_NVR_INFO_LEN]; /* ATI3: manufacturer info */
   unsigned char     info_4[ATC_NVR_INFO_LEN]; /* ATI4: manufacturer info */
   unsigned char     info_5[ATC_NVR_INFO_LEN]; /* ATI5: manufacturer info */
   unsigned char     info_6[ATC_NVR_INFO_LEN]; /* ATI6: manufacturer info */
   unsigned char     info_7[ATC_NVR_INFO_LEN]; /* ATI7: manufacturer info */
   unsigned char     info_8[ATC_NVR_INFO_LEN]; /* ATI8: manufacturer info */
   unsigned char     info_9[ATC_NVR_INFO_LEN]; /* ATI9: manufacturer info */

} eep_atc_static_parms_type;


typedef struct
{
   unsigned char     sca[ATC_NVR_SCA_LEN];    /* service center address */

   atc_nvr_profile_t profile_0;
   atc_nvr_profile_t profile_1;
   atc_sms_profile_t sms_profile;

   unsigned char     fill_char;               //Ensure correct word allignment

   unsigned char     greet[ATC_NVR_GREET_LEN];
   unsigned char     csca[MMI_NVR_CSCA_LEN];
   unsigned char     trace[ATC_NVR_TRACE_LEN];
   unsigned char     band_select[4];
   unsigned char     board_type[4];
   unsigned char     pres[4];
   unsigned char     pwrup_pro[4];
   unsigned char     gsm_paramp[ATC_NVR_GSM_PARAMP_LEN];
   unsigned char     dcs_paramp[ATC_NVR_DCS_PARAMP_LEN];
   unsigned char     pcs_paramp[ATC_NVR_PCS_PARAMP_LEN];
   unsigned char     smspp_pdu[ATC_NVR_SMSPP_PDU_LEN];
   unsigned char     ms_gprs_service[MS_GPRS_SERVICE_LEN];
   eep_t_msg_serv_settings serv_settings;   
} eep_atc_dynamic_parms_type;




typedef struct
{

  unsigned int16 check_enabled;
} eep_battery_verification_check_type;


/* BASEBAND configuration: */
typedef struct
{
  unsigned char epower_version;
  unsigned char egold_version;
  unsigned char spare1;
  unsigned char spare2;
} eep_baseband_config_type;


/* BFI parameters: */
typedef struct
{
  unsigned char fr_no_hop;      
  unsigned char fr_hop;         
  unsigned char efr_no_hop;     
  unsigned char efr_hop;        
  unsigned char fr_loop_back;   
  unsigned char hr_no_hop;      
  unsigned char hr_hop;         
  unsigned char hr_loop_back;   
} eep_bfi_type;

/* UFI parameters: */
typedef struct
{
  unsigned char hr_no_hop;
  unsigned char hr_hop;
  unsigned char hr_loop_back;
  unsigned char fill_char;
} eep_ufi_type;

/* hr_bfi_algorithm_type parameters: */ //Add By Comneon Rel 3.13 //William

typedef struct                    
{
  unsigned int16 window_size_N;   
  unsigned int16 hist_B_threshold;
  unsigned int16 hist_0_threshold;
  unsigned char  bfi_hr_loop_back1;
  unsigned char  bfi_hr_loop_back2;
  unsigned char  bfi_hr_loop_back3;
  unsigned char  ufi_hr_loop_back1;
  unsigned char  ufi_hr_loop_back2;
  unsigned char  ufi_hr_loop_back3;
} eep_hr_bfi_algorithm_type;

/*===== add by William Lo ======*/
typedef struct
{
  unsigned char serial_number[10];  /*modify by Tony Shu*/
  unsigned char assembly_ver[4];/*Tony Shu 2002/06/27*/
  unsigned char pcba_number[12];
  unsigned char mobile_number[12];
  unsigned char factory_id[3];
  unsigned char line_id[3];
  unsigned char bay_id[3];
  unsigned char test_info[26];
  unsigned char others[7];
  unsigned char cust_parms[128];
} eep_production_record_type;
/*===== add end =====*/
/*******added by macro lei SH-AGIT 2004/01/07***********/
typedef struct
{
	unsigned char data_time[14];
	unsigned char wakeup_info[16];
	unsigned char sensor_type;
	unsigned char brightness;
	unsigned char saturation;
	unsigned char hue[2];
}eep_camera_parameter;
/*******added end**************************************/
/* NSR parameters: */
typedef struct
{
  unsigned int16 threshold;
} eep_nsr_type;


/* SID parameters: */
typedef struct
{
  unsigned char  sid1_fr_normal;     
  unsigned char  sid1_fr_loop_back;  
  unsigned char  sid1_efr_normal;    
  unsigned char  sid1_efr_loop_back; 
  unsigned char  sid1_hr_normal;     
  unsigned char  sid1_hr_loop_back;  
  unsigned char  sid2_fr_normal;     
  unsigned char  sid2_fr_loop_back;  
  unsigned char  sid2_efr_normal;    
  unsigned char  sid2_efr_loop_back; 
  unsigned char  sid2_hr_normal;     
  unsigned char  sid2_hr_loop_back;  
} eep_sid_type;
/* Begin Add by Sammy Chen */
/* 2002-04-20 */
/* CI parameters: */
typedef struct
{
  unsigned char hs_sim_supported;      
  unsigned char fill_char;      
} eep_ci_type;


//GSM band configuartion:
typedef struct
{
  unsigned char nvr_nbr_band_config;      
  unsigned char fill_char;      
  unsigned char nvr_band_config_list[8];      
} eep_static_band_config_type;

typedef struct
{
  unsigned char  nvr_active_band_config[2];      
  unsigned char  nvr_auto_band_switch;      
  unsigned int16 nvr_band_switch_time;      
} eep_dynamic_band_config_type;
/* End Add by Sammy Chen */

//add by William Lo 2002/05/14
typedef struct
{
  unsigned char data[4];
} eep_dynamic_internal_type;

typedef struct
{
  signed int16 temp_offset[EEP_SIZE_AFC_TEMP_OFFSET];
} eep_dynamic_rf_afc_type;
// add end 2002/05/14

/* Begin - Add By Sammy Chen for Comneon Rel 4.0.3 */
typedef struct
{
  unsigned int16 hardware_flow_control_support;
} eep_flow_control_type;


/* types definitions for PLMN characteristics */
typedef char eep_long_plmn_name_type[EEP_MSAP_PLMN_LONG_NAME_LENGTH];
typedef char epp_short_plmn_name_type[EEP_MSAP_PLMN_SHORT_NAME_LENGTH];

typedef struct 
{
  unsigned int16            mcc;               /* Mobile Country Code */
  unsigned int16            mnc;               /* Mobile Network Code */
  unsigned int16            spare;             /* spare word for the further usage */
  eep_long_plmn_name_type   long_plmn_name;    /* Long PLMN name      */
  epp_short_plmn_name_type  short_plmn_name;   /* Short PLMN name     */
} eep_flash_plmn_item_type;


typedef struct 
{
  int16           c1_min_value;
  unsigned char   si_refresh_cycle;
  unsigned int16  t_sys_info_valid;
} eep_rr_parms_type;


/* SIM TK terminal profile */
typedef struct
{
  int16           length;
  unsigned char   data[EEP_MAX_TERM_PROFILE_LEN];
} eep_terminal_profile;
/* End - Add By Sammy Chen for Comneon Rel 4.0.3 */

// modify  for customized parameter by Sammy 05-09-2003
//Tags:
typedef struct
{
  unsigned char    greeting_tag;
  unsigned char    language_tag;
  unsigned char    input_method_tag;
  unsigned char    lcd_contrast_tag;
  unsigned char    format_display_mode_tag;
  unsigned char    melody_any_call_type_tag;
  unsigned char    sms_profile_1_status_tag;
  unsigned char    sms_profile_1_reply_tag;
  unsigned char    cb_menu_state_tag;
  unsigned char    ring_volume_tag;
  unsigned char    melody_pb_call_tag;
  unsigned char    melody_group_call_family_tag;
  unsigned char    melody_group_call_leisure_tag;
  unsigned char    melody_group_call_office_tag;
  unsigned char    melody_group_call_vip_tag;
  unsigned char    melody_alarm_tag;
  unsigned char    melody_cell_broadcast_tag;
  unsigned char    ringer_setting_tag;
  unsigned char    alarm_active_type_tag;
  unsigned char    auto_off_switch_state_tag;
  unsigned char    setup_backlight_period_tag;
  unsigned char    key_tone_tag;
  unsigned char    auto_key_lock_on_off_tag;
  unsigned char    any_key_answer_tag;
  unsigned char    auto_anser_on_off_tag;
  unsigned char    setup_prompt_in_call_tag;
  unsigned char    minute_beep_on_off_tag;
  unsigned char    auto_redial_on_off_tag;
  unsigned char    cmc_auto_display_tag;
  unsigned char    game_sound_tag;
  unsigned char    game_backlight_tag;
  unsigned char    game_vibrate_tag;
  unsigned char    screensaver_mode_tag;
  unsigned char    reserved[60-33];
} eep_tag_type;


typedef struct
{
  unsigned char    pmi_greeting_message_text[32];
} eep_greeting_text_type;

/* Definition of Default, Static and Dynamic EEP parameter types */
typedef struct
{
  eepchr_default_charger_parms_type  chr_charger;
  eepchr_default_capacity_parms_type chr_capacity;
  eepaud_default_dsp_parms_type      aud_dsp_parms[4];
  eeplcd_default_display_parms_type  lcd_parms;
} eep_default_type;
// add  for customized parameter by Sammy 05-09-2003
typedef struct
{
  unsigned char 		pmi_language[2];
  unsigned char 		pmi_t9_mode[2];
  unsigned char 		pmi_contrast;
  unsigned char 		pmi_format_display_mode[2];
  unsigned char 		pmi_melody_any_call_both_line;
  unsigned char 		pmi_sms_profile_1_status;
  unsigned char 		pmi_sms_profile_1_reply;
  unsigned char 		pmi_cb_menu_state;
  unsigned char 		pmi_ring_volume[2];
  unsigned char 		pmi_melody_pb_call;
  unsigned char 		pmi_melody_group_call_family;
  unsigned char 		pmi_melody_group_call_leisure;
  unsigned char 		pmi_melody_group_call_office;
  unsigned char 		pmi_melody_group_call_vip;
  unsigned char 		pmi_melody_alarm;
  unsigned char 		pmi_melody_cell_broadcast;
  unsigned char 		pmi_ringer_setting;
  unsigned char 		pmi_alarm_active_type;
  unsigned char 		pmi_auto_off_switch_state[2];
  unsigned char 		pmi_setup_backlight_period;
  unsigned char 		pmi_key_tone[2];
  unsigned char 		pmi_auto_key_lock_on_off;
  unsigned char 		pmi_any_key_answer[2];
  unsigned char 		pmi_auto_anser_on_off;
  unsigned char 		pmi_setup_prompt_in_call;
  unsigned char 		pmi_minute_beep_on_off;
  unsigned char 		pmi_auto_redial_on_off[2];
  unsigned char 		pmi_cmc_auto_display;
  unsigned char 		pmi_game_sound;
  unsigned char 		pmi_game_backlight;
  unsigned char 		pmi_game_vibrate;
  unsigned char 		pmi_screensaver_mode[2];
} eep_tag_context_type;



typedef struct
{
  eeprf_comp_parm_type                rf_comp;
  eeprf_adjusted_comp_parm_type       rf_adjcomp;
  eepchr_adc_adjusted_comp_parms_type chr_adjcomp;
  eepatc_startup_info_type            atc_startup;
  eepaud_static_parms_type            aud_scal_parms[4];
  eeplcd_static_display_parms_type    lcd_parms;
  eep_production_parm_type            production_parms;
  eep_greeting_graphic_type           greeting_graphic;
  eepchr_mic_parms_type               chr_mic_parms;
  eep_external_audio_type             external_audio;
  eepchr_gg_dram_type                 chr_gg_dram;
  eepchr_pmb6253_type                 chr_pmb6253;
  eep_obsolete_atc_static_parms_type  dummy_parms;
  eep_battery_verification_check_type battery_verification;
  eep_baseband_config_type            base_band_config;
  eep_bfi_type                        bfi;
  eep_atc_static_parms_type           atc_parms;
  eep_ci_type                         ci_parms;   // Modify by Comneon Rel 3.17         
  eep_static_band_config_type         gsm_band_config;    // Modify by Comneon Rel 3.17  
  eep_ufi_type                        ufi;  // Add by Comneon Rel 3.11, // Change position by Fatty, 2002/05/30
  eep_hr_bfi_algorithm_type           hrbfi_alg; // Add by Comneon Rel 3.13 // Change position by Fatty, 2002/05/30
  eep_flow_control_type               flow_control;		//Add By Sammy Chen for Comneon Rel 4.0.3
  eep_flash_plmn_item_type            plmn_list[EEP_FLASH_PLMN_LIST_LENGTH];	//Add By Sammy Chen for Comneon Rel 4.0.3
  eep_terminal_profile                terminal_profile;		//Add By Sammy Chen for Comneon Rel 4.0.3
  // !! Attention: Ares's static data add below here, please !!
  /*=============== add by William Lo====================*/
  eep_production_record_type          eep_production_record;
  /*=================== add end ========================*/
  //added by macro lei begin
  eep_camera_parameter		camera_parameters;
  //added by macro lei end
  eep_nsr_type                        nsr;
  eep_sid_type                        sid;
  eep_greeting_text_type              greeting;
  eep_tag_type                        tags;
  eep_tag_context_type		      tags_context;	// add  for customized parameter by Sammy 05-09-2003
} eep_static_type;


typedef struct
{
  eeprtc_dynamic_parms_type  rtc;
  eepchr_dynamic_parms_type  chr;
  eepaud_dynamic_parms_type  aud_eep_parms[4];
  eep_mmi_parms_type         mmi;
  eep_sp_unlock_type         sp_unlock;
  eep_ll_trace_type          ll_trace;
  eep_atc_dynamic_parms_type atc_parms;
  eep_dynamic_band_config_type gsm_band_config;	// Add by Sammy Chen 2002-04-20
  eep_dynamic_internal_type    internal;        // Add by William Lo 2002/05/14
  eep_dynamic_rf_afc_type      afc;             // Add by William Lo 2002/05/14
  eep_rr_parms_type            rr_parms;		//Add By Sammy Chen for Comneon Rel 4.0.3
  eep_terminal_profile         terminal_profile;	//Add By Sammy Chen for Comneon Rel 4.0.3
  eep_tag_type                 tags;
} eep_dynamic_type;


typedef struct
{
  eep_static_type  eep_static;
  eep_dynamic_type eep_dynamic;
} eep_parms_type;

/*---------------------------------------------*/
/* External declarations                       */
/*---------------------------------------------*/
extern const eep_default_type       EEP_default;
extern const eep_static_type        EEP_static;
extern const eep_dynamic_type shuge EEP_dynamic;
extern const eep_dynamic_type shuge EEP_dynamic_default_filter;
extern const unsigned char    shuge EEP_dynamic_factory[EEP_DYNAMIC_FACTORY_SIZE];

#endif

/*******************************************************************************
* History log:
*===============================================================================
* $Log: eep.h,v $
* Revision 12.2  2002/08/12 13:21:23  ec
*  - EEPROM version changed to 34.
*  - eep_flash_plmn_item_type changed in EEP_static.
*
* Revision 12.1  2002/08/06 15:01:13  ec
*  - EEPROM version changed to 33.
*  - Dynamic Radio Ressource parameters added.
*
* Revision 12.0  2002/07/15 10:43:17  pbo
* EE64K_10
*
* Revision 11.1  2002/07/14 13:59:30  ec
*  - EEPROM version changed to 32.
*  - Flow control parameter added to EEP_static.
*  - PLMN list added to EEP_static.
*
* Revision 11.0  2002/06/19 13:03:57  knm
* EE_10
*
* Revision 10.2  2002/06/06 13:01:12  ec
*  - EEPROM version changed to 31.1.
*  - Default values changed for "hrbfi_alg" parameters.
*
* Revision 10.1  2002/06/04 09:23:10  ec
*  - EEPROM version changed to 31.
*  - "fill_char" added to "gsm_band_config" structure to ensure correct allignment
*    between target and the PC-tools.
* Revision 10.0  2002/05/29 10:17:34  pbo
* EE_9
*
* Revision 9.1  2002/05/29 10:12:44  ec
*  - EEPROM version changed to 30.
*  - New Halfrate BFI parameters added to the static EEPROM.
*
* Revision 9.0  2002/05/24 13:35:05  pbo
* EE_8
*
* Revision 8.1  2002/05/24 13:29:49  ec
*  - EEPROM version changed to 29.
*  - UFI parameters added to the static EEPROM.
*  - Default values changed for BFI parameters.
*
* Revision 8.0  2002/05/03 12:59:12  pbo
* EE_7
*
* Revision 7.1  2002/05/03 12:58:20  ec
*  - EEPROM version changed to 28.
*  - New parameters for internal use added to the dynamic block.
*  - New functions to access to the above parameters added.
*  - New parameters for RF-AFC added to the dynamic block.
*
* Revision 7.0  2002/04/29 12:41:19  pbo
* EE_6
*
* Revision 6.1  2002/04/23 07:42:09  ec
*  - Defines for accessory/trace conflict handling added.
*
* Revision 6.0  2002/04/12 11:03:35  pbo
* EE_5
*
* Revision 5.1  2002/04/12 10:43:03  ec
*  - EEP version changed to 27.1.
*  - Audio parameters with changed default values in EEP_default.
*  - Audio parameters with changed default values in EEP_static.
*
* Revision 5.0  2002/04/12 09:58:38  pbo
* EE_4
*
* Revision 4.3  2002/04/10 11:14:44  ec
*  - New EEP_default charger parameters added: "dt_eoc", "dv_eoc".
*
* Revision 4.2  2002/04/02 13:58:54  ec
*  - EEPROM version changed to 27.
*  - Parameter "msg_serv_settings" added to the dynamic ATC-parameters.
*  - GSM band config parameters added to static and dynamic sections.
*  - Default values changed for the dynamic ATC parameters "profile_0.k" and "profile_1.k".
*
* Revision 4.1  2002/03/06 11:46:33  ec
*  - EEPROM version changed to 26.
*  - Parameter "hs_sim_supported" added to the static block.
*

* Revision 4.?   2002/04/01
* Add eep_static.eep_production_record, eep.dynamic.mmi by William Lo, Ares
* 
* Revision 4.0  2002/03/01 09:49:41  pbo
* EE_3
*
* Revision 3.5  2002/02/28 11:36:36  ec
* no message
*
* Revision 3.4  2002/02/22 08:09:56  ec
*  - Define "BATTERY_WITH_FUEL_GAUGE" used to select correct charger parameters.
*
* Revision 3.3  2002/02/19 12:26:59  ec
*  - EEPROM version changed to 25.
*  - #define _EEP_H added.
*  - ATC parameter structures changed for the dynamic EEPROM.
*  - ATC parameter structures changed for the static EEPROM.
*    The old ATC-structure is now a dummy-area.
*  - New MMI parameters added.
*  - Two charger algorithms supported in "EEP_default".
*
* Revision 3.2  2002/02/04 13:45:00  ec
*  - Charger concept changed to "Voltage based capacity estimation".
*
* Revision 3.1  2002/01/28 15:43:01  ec
*  - EEPROM version changed to 24.
*  - New MMI parameters added.
*
* Revision 3.0  2002/01/10 11:08:37  pbo
* EE_2
*
* Revision 2.0  2002/01/09 12:50:27  pbo
* EE_1
*
* Revision 1.1.1.1  2002/01/09 12:47:32  pbo
* Initial version
*
* Revision 29.1  2001/12/17 12:25:50  ec
*  - EEPROM version changed to 23.1.
*  - Default values changed for the static parameter "rxlev_temp_comp".
*
*******************************************************************************/
